@@ -3,7 +3,7 @@ def merge_two_dicts(x, y):
     z = x.copy()   
     z.update(y)
     return z
-	
+    
 def get_value_type(value):       
     if type(value) is bool:
         value_type = "bool"
@@ -18,12 +18,12 @@ def get_value_type(value):
     else:
         value_type = ""
     return value_type
-	
+    
 def is_same_type(value, expected_type):
     valueType = get_value_type(value)
-    valid = False
     valid = (valueType == expected_type)
-	
+    return valid
+    
 def get_properties_from_header_file(file_path):
     # Parse header file to get the list of properties
     with open(file_path) as f:
@@ -32,6 +32,6 @@ def get_properties_from_header_file(file_path):
         .replace("\"", "") \
         .replace("\n", "") \
         .replace("\\", "")  \
-        .replace("\/", "")
+        .replace("//", "")
     properties_list = header.split(",")
     return properties_list
